@@ -24,7 +24,7 @@ sub test_redis(&) {
         },
         client => sub {
             my $port = shift;
-            my $r = AnyEvent::Redis->new("127.0.0.1:$port");
+            my $r = AnyEvent::Redis->new(host => "127.0.0.1", port => $port);
             $cb->($r);
         };
 }
